indexing
	description: "Wrapper for a generic C structure"
	copyright: "(C) 2005 Paolo Redaelli <paolo.redaelli@poste.it>"
	license: "LGPL v2 or later"
	date: "$Date:$"
	revision "$REvision:$"


deferred class C_STRUCT

inherit
	WRAPPER
	
	GLIB_MEMORY_ALLOCATION
	
	DISPOSABLE -- Note: use this instead of "MEMORY redefine dispose end" to define dispose 

	ANY undefine is_equal, copy end
	
insert
	EXCEPTIONS
	
feature {NONE} -- Initialization
	make is
			-- Allocate an initialized structure
		do
			handle := g_try_malloc0 (size)
			if handle.is_null then raise_exception (No_more_memory) end
			-- This post-condition does not held for G_SLISTs!
			-- ensure memory_allocated: handle.is_not_null
		end

feature -- Access to C features
	size: INTEGER is
			-- sizeof (wrapped_structure), speaking in C. TODO: shall be a NATURAL
		deferred
		ensure positive: Result>0 -- TODO: having NATURAL it is plainly useless
		end

	exists: BOOLEAN is
			--  Does Current wrap an existing object? i.e. is handle NULL?
		do
			Result := handle.is_not_null
		end

	is_shared: BOOLEAN 
			-- Does anybody else (Eiffel or non-Eiffel) have a reference 
			-- to `handle'? If False, then the C-object will be 
			-- destroyed when the the Eiffel object will be collected 
			-- (via destroy object). If True the C-object will not be destroyed.

feature {NONE} -- Destroying
	dispose is
			-- Action to be executed just before garbage collection reclaims an 
			-- object; frees the memory pointed by `handle'
		do
			g_free (handle)
			handle:=Null
			-- Not useful handle := default_pointer -- i.e. NULL for C people
			-- Note: we can liberally call g_free; infact if handle is NULL it
			-- simply returns.
		ensure doesnt_exists: not exists
		end

end

